C     -*- fortran -*-
C     This file is autogenerated with f2py (version:2)
C     It contains Fortran 77 wrappers to fortran functions.

      subroutine f2pywrapareap (areapf2pywrap, x, y, nb, nodes)
      external areap
      integer(kind=4) nb
      real(kind=8) x(*)
      real(kind=8) y(*)
      integer(kind=4) nodes(nb)
      real(kind=8) areapf2pywrap, areap
      areapf2pywrap = areap(x, y, nb, nodes)
      end


      subroutine f2pywrapnearnd (nearndf2pywrap, xp, yp, ist, n, x
     &, y, list, lptr, lend, dsq)
      external nearnd
      real(kind=8) xp
      real(kind=8) yp
      integer(kind=4) ist
      integer(kind=4) n
      real(kind=8) dsq
      real(kind=8) x(n)
      real(kind=8) y(n)
      integer(kind=4) list(6 * n - 12)
      integer(kind=4) lptr(6 * n - 12)
      integer(kind=4) lend(n)
      integer(kind=4) nearndf2pywrap, nearnd
      nearndf2pywrap = nearnd(xp, yp, ist, n, x, y, list, lptr, le
     &nd, dsq)
      end

